#' @importFrom paradox ps
#' @export
paradox::ps

#' @importFrom paradox p_lgl
#' @export
paradox::p_lgl

#' @importFrom paradox p_int
#' @export
paradox::p_int

#' @importFrom paradox p_dbl
#' @export
paradox::p_dbl

#' @importFrom paradox p_fct
#' @export
paradox::p_fct

#' @importFrom paradox p_uty
#' @export
paradox::p_uty

#' @importFrom paradox to_tune
#' @export
paradox::to_tune

#' @importFrom paradox generate_design_grid
#' @export
paradox::generate_design_grid

#' @importFrom paradox generate_design_lhs
#' @export
paradox::generate_design_lhs

#' @importFrom paradox generate_design_random
#' @export
paradox::generate_design_random
